@@ -7,10 +7,12 @@ type Language struct {
 
 // Supported Languages
 const (
-	Bash   = "bash"
-	Go     = "go"
-	Ruby   = "ruby"
-	Python = "python"
+	Bash       = "bash"
+	Elixir     = "elixir"
+	Go         = "go"
+	Javascript = "javascript"
+	Python     = "python"
+	Ruby       = "ruby"
 )
 
 var Languages = map[string]Language{
@@ -18,10 +20,18 @@ var Languages = map[string]Language{
 		Extension: "sh",
 		Command:   []string{"bash"},
 	},
+	Elixir: {
+		Extension: "exs",
+		Command:   []string{"elixir"},
+	},
 	Go: {
 		Extension: "go",
 		Command:   []string{"go", "run"},
 	},
+	Javascript: {
+		Extension: "js",
+		Command:   []string{"node"},
+	},
 	Ruby: {
 		Extension: "rb",
 		Command:   []string{"ruby"},
