@@ -4,22 +4,24 @@ import (
 	"bufio"
 	"errors"
 	"fmt"
-	"github.com/charmbracelet/bubbles/viewport"
-	tea "github.com/charmbracelet/bubbletea"
-	"github.com/charmbracelet/glamour"
-	"github.com/maaslalani/slides/internal/code"
-	"github.com/maaslalani/slides/internal/meta"
-	"github.com/maaslalani/slides/styles"
 	"io"
 	"io/ioutil"
 	"os"
 	"strings"
 	"time"
+
+	"github.com/charmbracelet/bubbles/viewport"
+	tea "github.com/charmbracelet/bubbletea"
+	"github.com/charmbracelet/glamour"
+	"github.com/maaslalani/slides/internal/code"
+	"github.com/maaslalani/slides/internal/file"
+	"github.com/maaslalani/slides/internal/meta"
+	"github.com/maaslalani/slides/internal/process"
+	"github.com/maaslalani/slides/styles"
 )
 
 const (
-	delimiter    = "\n---\n"
-	altDelimiter = "\n~~~\n"
+	delimiter = "\n---\n"
 )
 
 type Model struct {
@@ -67,7 +69,6 @@ func (m *Model) Load() error {
 		return err
 	}
 
-	content = strings.ReplaceAll(content, altDelimiter, delimiter)
 	slides := strings.Split(content, delimiter)
 
 	metaData, exists := meta.New().ParseHeader(slides[0])
@@ -96,12 +97,12 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 		switch msg.String() {
 		case "ctrl+c", "q":
 			return m, tea.Quit
-		case " ", "down", "k", "right", "l", "enter", "n":
+		case " ", "down", "j", "right", "l", "enter", "n":
 			if m.Page < len(m.Slides)-1 {
 				m.Page++
 			}
 			m.VirtualText = ""
-		case "up", "j", "left", "h", "p":
+		case "up", "k", "left", "h", "p":
 			if m.Page > 0 {
 				m.Page--
 			}
@@ -135,8 +136,8 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 func (m Model) View() string {
 	r, _ := glamour.NewTermRenderer(m.Theme, glamour.WithWordWrap(0))
 	slide := m.Slides[m.Page]
-	slide += m.VirtualText
 	slide, err := r.Render(slide)
+	slide += m.VirtualText
 	if err != nil {
 		slide = fmt.Sprintf("Error: Could not render markdown! (%v)", err)
 	}
@@ -160,7 +161,15 @@ func readFile(path string) (string, error) {
 	if err != nil {
 		return "", err
 	}
-	return string(b), err
+	content := string(b)
+
+	// Pre-process slides if the file is executable to avoid
+	// unintentional code execution when presenting slides
+	if file.IsExecutable(s) {
+		content = process.Pre(content)
+	}
+
+	return content, err
 }
 
 func readStdin() (string, error) {
